@@ -21,22 +21,19 @@ struct Args {
 }
 
 pub fn main() {
-    let args: Args = Docopt::new(USAGE)
-        .and_then(|d| d.deserialize())
-        .unwrap_or_else(|e| e.exit());
+    let args: Args = get_args(USAGE);
+
     for callsign in args.arg_callsign {
         let callpass: Callpass = (&callsign).into();
-        show(&callsign, &callpass, &args.flag_verbose)
+        match args.flag_verbose {
+            true => println!("{} {}", callpass, callsign),
+            false => println!("{}", callpass),
+        };
     }
 }
 
-fn show(callsign: &str, callpass: &Callpass, verbose: &bool) {
-    match *verbose {
-        false => {
-            println!("{}", callpass);
-        }
-        true => {
-            println!("{} {}", callpass, callsign);
-        }
-    }
+fn get_args(usage: &str) -> Args {
+    Docopt::new(usage)
+        .and_then(|d| d.deserialize())
+        .unwrap_or_else(|e| e.exit())
 }
